PreviewVariant

Enum PreviewVariant 

pub enum PreviewVariant {
    Knobs {
        name: &'static str,
        overrides: KnobOverrides,
    },
    Scenario {
        name: &'static str,
        builder: ScenarioBuilder,
    },
}

Variants



Knobs

Knob preset — WidgetCatalog::build runs and consults knobs() to build the widget; the supplied overrides are applied on top of the spec’s defaults.

Fields

name: &'static str
overrides: KnobOverrides


Scenario

Hand-authored scenario — WidgetCatalog::build ignores its KnobValues argument when this variant is selected and instead dispatches to the captured builder fn.

Fields

name: &'static str

Implementations

Source

impl PreviewVariant

pub fn name(&self) -> &'static str

pub fn knobs(name: &'static str, overrides: KnobOverrides) -> Self

pub fn defaults(name: &'static str) -> Self

pub fn scenario(name: &'static str, builder: ScenarioBuilder) -> Self